BUILD_BIT = '64bit'
BUILD_CPU = 'AMD Ryzen 9 7900X 12-Core Processor'
BUILD_DATE = '2025-10-05'
BUILD_MACHINE = 'x86_64'
BUILD_OS = 'linux'
BUILD_TIME = '01:59'
BUILD_TYPE = ''
COMPILER_VERSION = 'gcc (GCC) 15.2.1 20250813'
CYTHON_VERSION = '3.1.4'
LINKER_VERSION = 'GNU ld (GNU Binutils) 2.45.0'
NVCC_VERSION = ''
PYTHON_VERSION = '3.13.7'
lib_gobjectintrospection10 = '1.86.0'
lib_gtk30 = '3.24.51'
lib_gtkx1130 = '3.24.51'
lib_py3cairo = '1.28.0'
lib_pygobject30 = '3.54.3'
lib_python3 = '3.13'
lib_vpx = '1.15.2'
lib_x11 = '1.8.12'
lib_x264 = '0.165.3222'
lib_xcomposite = '0.4.6'
lib_xdamage = '1.1.6'
lib_xext = '1.3.6'
lib_xfixes = '6.0.2'
lib_xkbfile = '1.1.3'
lib_xrandr = '1.5.4'
lib_xtst = '1.2.5'
